Requirements:
 * Python >= 3

To run examples:

```bash
git clone https://github.com/coinapi/coinapi-sdk/
cd coinapi-sdk/python-rest/coinapi_rest_v1
# edit examples.py, fill your API key inside of it
python examples.py YOUR_API_KEY
```
